#include <LiquidCrystal.h>
#include<IRremote.h>
#include <Adafruit_NeoPixel.h>

#define PIN_NEO_PIXEL 6  // Arduino pin that connects to NeoPixel
#define NUM_PIXELS 6    // The number of LEDs (pixels) on NeoPixel
#define DIGIT_ON  LOW
#define DIGIT_OFF  HIGH
Adafruit_NeoPixel NeoPixel(NUM_PIXELS, PIN_NEO_PIXEL, NEO_GRB + NEO_KHZ800);

const int hot = 30; //set hot parameter, change for oven
const int ovenon = 70; // set parameter for telling if oven is on
const int TEMP_PIN = A1;
int speakerPin = 8;

int RECV_PIN = 11;
IRrecv irrecv(RECV_PIN);
decode_results results;
LiquidCrystal lcd(10, 9, 5, 4, 3, 2);

unsigned long lastTempUpdateTime = 0;
const int tempUpdateInterval = 1000;  // Update temperature every 1000 milliseconds (1 second)

unsigned long timeEnded = 0;
boolean waitingToTest = false;

int minutes = 0;


void setup() {
  NeoPixel.begin();  // INITIALIZE NeoPixel strip object (REQUIRED)
  pinMode(speakerPin,  OUTPUT);

  lcd.begin(16, 2);
  lcd.write("Enter Time:");
  lcd.setCursor(9, 2);
  lcd.write("minutes");
  lcd.setCursor(0, 1); lcd.blink();
  irrecv.enableIRIn();
  Serial.begin(9600);
}

void  playTone(int tone, int duration) {
  for (long k = 0; k < duration * 1000L; k  += tone * 2) {  
    digitalWrite(speakerPin, HIGH);
    delayMicroseconds(tone);
    digitalWrite(speakerPin, LOW);
    delayMicroseconds(tone);
  }
}

void tempIndicator(){
  // Read temperature
  float tempC = 100 * ((analogRead(TEMP_PIN) * 5.0 / 1024) - 0.5);
  float tempF = (tempC * 1.8) + 32;
  //Serial.print("Temperature: ");
  //Serial.println(tempF);


  NeoPixel.clear(); // Set all pixel colors to zero (off)

  // Ensure at least one pixel is lit up
  NeoPixel.setPixelColor(0, NeoPixel.Color(255, 0, 0));

  if (tempF >= hot) {
    // If temperature is above the hot parameter, light up additional pixels in red
    int pixelsToLight = min(int((tempF - hot) / 50), NUM_PIXELS); //calculates how many pixels to light up based on current temp and 20º increments
    for (int pixel = 1; pixel < pixelsToLight; pixel++) {
      NeoPixel.setPixelColor(pixel, NeoPixel.Color(255, 0, 0));
    }

  } 
  //doesnt show
  else {
    // If temperature is below the hot parameter, set NeoPixels to blue
    for (int pixel = 0; pixel < NUM_PIXELS; pixel++) {
      NeoPixel.setPixelColor(pixel, NeoPixel.Color(0, 0, 255));
    }
  }

  NeoPixel.show();
}

String x = "";
int y = 0;

void loop(){
  if(waitingToTest && (unsigned long)(millis() - timeEnded) >= 10000) {
    waitingToTest = false;
    float tempC = 100*((analogRead(TEMP_PIN)*5.0 / 1024)-0.5);
    float tempF = (tempC * 1.8) + 32;
    if (tempF >= ovenon) { //hot
      lcd.clear();
      lcd.noCursor();
      lcd.print("OVEN IS ON");

      playTone(1519,1000);
        for (int flash = 0; flash < 5; flash++) {
          for (int pixel = 0; pixel < NUM_PIXELS; pixel++) {
            NeoPixel.setPixelColor(pixel, NeoPixel.Color(255, 0, 0));
            }
            NeoPixel.show();
            playTone(2000,3000);
            delay(300);
            NeoPixel.clear();
            NeoPixel.show();
            delay(300);
            // waitingToTest = false?
      }
    }

  }
  
if (irrecv.decode(&results))
  {
    switch (results.value)
    {
      case 0xFFB04F: lcd.clear(); lcd.print("Enter Time:"); lcd.setCursor(9, 2); lcd.write("minutes"); x = ""; lcd.setCursor(0, 1); lcd.blink(); break; //reset
      case 0xFF02FD:
        y = x.toInt() * 60;
        for (int i = y; i >= 0; i--) {
          if (i == 0) {
            for (int flash = 0; flash < 5; flash++) {
                for (int pixel = 0; pixel < NUM_PIXELS; pixel++) {
                  NeoPixel.setPixelColor(pixel, NeoPixel.Color(0, 255, 0));
                  }
                  NeoPixel.show();
                  playTone(2000,3000);
                  delay(300);
                  NeoPixel.clear();
                  NeoPixel.show();
                  delay(300);
            }

            lcd.clear();
            lcd.noCursor();
            lcd.print("TIME's UP");
            playTone(1519,1000);
            timeEnded = millis();
            waitingToTest = true;
            break;
          }

          lcd.noCursor();
          lcd.clear();
          lcd.setCursor(0, 0);
          lcd.print("Remaining Time:");
          lcd.setCursor(0, 1);
          lcd.print(i / 60, DEC);
          lcd.print(":");
          if(i % 60 < 10) {
            lcd.print("0");
          }
          lcd.print(i % 60, DEC);
          // lcd.setCursor(9, 2);
          // lcd.print("seconds");
          delay(999);
        }     break;            //PLAY/PAUSE

      case 0xFF6897:           x = x + "0"; lcd.setCursor(0, 1); lcd.print(x); break;       //0
      case 0xFF30CF:           x = x + "1"; lcd.setCursor(0, 1); lcd.print(x); break;       //1
      case 0xFF18E7:           x = x + "2"; lcd.setCursor(0, 1); lcd.print(x); break;       //2
      case 0xFF7A85:           x = x + "3"; lcd.setCursor(0, 1); lcd.print(x); break;       //3
      case 0xFF10EF:           x = x + "4"; lcd.setCursor(0, 1); lcd.print(x); break;       //4
      case 0xFF38C7:           x = x + "5"; lcd.setCursor(0, 1); lcd.print(x); break;       //5
      case 0xFF5AA5:           x = x + "6"; lcd.setCursor(0, 1); lcd.print(x); break;       //6
      case 0xFF42BD:           x = x + "7"; lcd.setCursor(0, 1); lcd.print(x); break;       //7
      case 0xFF4AB5:           x = x + "8"; lcd.setCursor(0, 1); lcd.print(x); break;       //8
      case 0xFF52AD:           x = x + "9"; lcd.setCursor(0, 1); lcd.print(x); break;       //9
    }
    irrecv.resume();
  }
  if (millis() - lastTempUpdateTime >= tempUpdateInterval) {
    tempIndicator();
    lastTempUpdateTime = millis();
  }
  
  }
  
